@@ -243,6 +243,11 @@ data = {
                         "help": "create annotated tag instead of lightweight one",
                         "action": "store_true",
                     },
+                    {
+                        "name": ["--annotated-tag-message", "-atm"],
+                        "help": "create annotated tag message",
+                        "type": str,
+                    },
                     {
                         "name": ["--gpg-sign", "-s"],
                         "help": "sign tag instead of lightweight one",
